@@ -2,30 +2,29 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import re
-from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
+import regex as re
 
 from cfnlint.helpers import RESOURCE_SPECS
+from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
 
 class AllowedPattern(CloudFormationLintRule):
     """Check if properties have a valid value"""
 
-    id = 'E3031'
-    shortdesc = 'Check if property values adhere to a specific pattern'
-    description = 'Check if properties have a valid value in case of a pattern (Regular Expression)'
-    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedpattern'
-    tags = ['resources', 'property', 'allowed pattern', 'regex']
+    id = "E3031"
+    shortdesc = "Check if property values adhere to a specific pattern"
+    description = "Check if properties have a valid value in case of a pattern (Regular Expression)"
+    source_url = "https://github.com/awslabs/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedpattern"
+    tags = ["resources", "property", "allowed pattern", "regex"]
 
     def __init__(self):
         """Init"""
         super().__init__()
         self.config_definition = {
-            'exceptions': {
-                'default': [],
-                'type': 'list',
-                'itemtype': 'string',
+            "exceptions": {
+                "default": [],
+                "type": "list",
+                "itemtype": "string",
             }
         }
         self.configure()
@@ -33,11 +32,11 @@ class AllowedPattern(CloudFormationLintRule):
     def initialize(self, cfn):
         """Initialize the rule"""
         for resource_type_spec in RESOURCE_SPECS.get(cfn.regions[0]).get(
-            'ResourceTypes'
+            "ResourceTypes"
         ):
             self.resource_property_types.append(resource_type_spec)
         for property_type_spec in RESOURCE_SPECS.get(cfn.regions[0]).get(
-            'PropertyTypes'
+            "PropertyTypes"
         ):
             self.resource_sub_property_types.append(property_type_spec)
 
@@ -46,13 +45,13 @@ class AllowedPattern(CloudFormationLintRule):
         matches = []
 
         # Get the Allowed Pattern Regex
-        value_pattern_regex = kwargs.get('value_specs', {}).get(
-            'AllowedPatternRegex', {}
+        value_pattern_regex = kwargs.get("value_specs", {}).get(
+            "AllowedPatternRegex", {}
         )
         # Get the "Human Readable" version for the error message. Optional, if not specified,
         # the RegEx itself is used.
-        value_pattern = kwargs.get('value_specs', {}).get(
-            'AllowedPattern', value_pattern_regex
+        value_pattern = kwargs.get("value_specs", {}).get(
+            "AllowedPattern", value_pattern_regex
         )
 
         if isinstance(value, (int, float)):
@@ -64,15 +63,15 @@ class AllowedPattern(CloudFormationLintRule):
 
                 # Ignore values with dynamic references. Simple check to prevent false-positives
                 # See: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html
-                if '{{resolve:' not in value:
+                if "{{resolve:" not in value:
                     if not regex.match(value):
-                        for exception in self.config.get('exceptions'):
+                        for exception in self.config.get("exceptions"):
                             exception_regex = re.compile(exception)
                             if exception_regex.match(value):
                                 return matches
-                        full_path = '/'.join(str(x) for x in path)
+                        full_path = "/".join(str(x) for x in path)
 
-                        message = '{} contains invalid characters (Pattern: {}) at {}'
+                        message = "{} contains invalid characters (Pattern: {}) at {}"
                         matches.append(
                             RuleMatch(
                                 path,
@@ -88,21 +87,30 @@ class AllowedPattern(CloudFormationLintRule):
         for p_value, p_path in properties.items_safe(path[:]):
             for prop in p_value:
                 if prop in value_specs:
-                    value = value_specs.get(prop).get('Value', {})
+                    value = value_specs.get(prop).get("Value", {})
                     if value:
-                        value_type = value.get('ValueType', '')
+                        value_type = value.get("ValueType", "")
                         property_type = (
-                            property_specs.get('Properties').get(prop).get('Type')
+                            property_specs.get("Properties").get(prop).get("Type")
                         )
+                        value_specs = (
+                            RESOURCE_SPECS.get(cfn.regions[0])
+                            .get("ValueTypes")
+                            .get(value_type, {})
+                        )
+                        if value_specs == "CACHED":
+                            value_specs = (
+                                RESOURCE_SPECS.get("us-east-1")
+                                .get("ValueTypes")
+                                .get(value_type, {})
+                            )
                         matches.extend(
                             cfn.check_value(
                                 p_value,
                                 prop,
                                 p_path,
                                 check_value=self.check_value,
-                                value_specs=RESOURCE_SPECS.get(cfn.regions[0])
-                                .get('ValueTypes')
-                                .get(value_type, {}),
+                                value_specs=value_specs,
                                 cfn=cfn,
                                 property_type=property_type,
                                 property_name=prop,
@@ -116,12 +124,12 @@ class AllowedPattern(CloudFormationLintRule):
 
         specs = (
             RESOURCE_SPECS.get(cfn.regions[0])
-            .get('PropertyTypes')
+            .get("PropertyTypes")
             .get(property_type, {})
-            .get('Properties', {})
+            .get("Properties", {})
         )
         property_specs = (
-            RESOURCE_SPECS.get(cfn.regions[0]).get('PropertyTypes').get(property_type)
+            RESOURCE_SPECS.get(cfn.regions[0]).get("PropertyTypes").get(property_type)
         )
         matches.extend(self.check(cfn, properties, specs, property_specs, path))
 
@@ -133,12 +141,12 @@ class AllowedPattern(CloudFormationLintRule):
 
         specs = (
             RESOURCE_SPECS.get(cfn.regions[0])
-            .get('ResourceTypes')
+            .get("ResourceTypes")
             .get(resource_type, {})
-            .get('Properties', {})
+            .get("Properties", {})
         )
         resource_specs = (
-            RESOURCE_SPECS.get(cfn.regions[0]).get('ResourceTypes').get(resource_type)
+            RESOURCE_SPECS.get(cfn.regions[0]).get("ResourceTypes").get(resource_type)
         )
         matches.extend(self.check(cfn, properties, specs, resource_specs, path))
 
